CallableBond-class: Callable (and putable) corporate or government bond.

CallableBond-classR Documentation

Callable (and putable) corporate or government bond.

Description

When a bond is callable, the issuer may choose to pay the call price to the bond holder and end the life of the contract.

Details

When a bond is putable, the bond holder may choose to force the issuer pay the put price to the bond holder thus ending the life of the contract.

Fields

calls

A data.frame of details for each call. It should have the columns call_price and effective_time.

puts

A data.frame of details for each put. It should have the columns put_price and effective_time.

Methods

critical_times()

Important times in the life of this instrument for simulation and grid solvers


ragtop documentation built on June 20, 2026, 5:06 p.m.