TIME_RESOLUTION_FACTOR: Constant to define when times are considered so close to each...

TIME_RESOLUTION_FACTORR Documentation

Constant to define when times are considered so close to each other that they should be treated as simultaneous

Description

Constant to define when times are considered so close to each other that they should be treated as simultaneous

Usage

TIME_RESOLUTION_FACTOR

ragtop documentation built on June 20, 2026, 5:06 p.m.