TIME_RESOLUTION_SIGNIF_DIGITS: Constant to define when times are considered so close to each...

TIME_RESOLUTION_SIGNIF_DIGITSR Documentation

Constant to define when times are considered so close to each other that they should be treated as simultaneous, in terms of significant digits

Description

Constant to define when times are considered so close to each other that they should be treated as simultaneous, in terms of significant digits

Usage

TIME_RESOLUTION_SIGNIF_DIGITS

ragtop documentation built on June 20, 2026, 5:06 p.m.