| black_scholes_on_term_structures | R Documentation |
Price an option according to the famous Black-Scholes formula, with the
optional addition of a jump-to-default intensity and discrete dividends. Volatility
and rates may be provided as constants or as 2+ parameter functions with
first argument T corresponding to maturity and second argument t corresponding to
model date.
black_scholes_on_term_structures(
callput,
S0,
K,
time,
const_volatility = 0.5,
const_short_rate = 0,
const_default_intensity = 0,
discount_factor_fcn = function(T, t, ...) {
exp(-const_short_rate * (T - t))
},
survival_probability_fcn = function(T, t, ...) {
exp(-const_default_intensity * (T
- t))
},
variance_cumulation_fcn = function(T, t) {
const_volatility^2 * (T - t)
},
dividends = NULL,
borrow_cost = 0,
dividend_rate = 0
)
callput |
|
S0 |
initial underlying price |
K |
strike |
time |
Time from |
const_volatility |
A constant to use for volatility in case |
const_short_rate |
A constant to use for the instantaneous interest rate in case |
const_default_intensity |
A constant to use for the instantaneous default intensity in case |
discount_factor_fcn |
A function for computing present values to
time |
survival_probability_fcn |
A function for probability of survival, with
arguments |
variance_cumulation_fcn |
A function for computing total stock variance
occurring during this timestep, with arguments |
dividends |
A |
borrow_cost |
A continuous rate for stock borrow costs |
dividend_rate |
A continuous rate for dividends and other cashflows such as foreign interest rates |
Any term structures will be converted to equivalent constant arguments by calling
them with the arguments (time, 0).
Other European Options:
blackscholes(),
implied_volatilities(),
implied_volatilities_with_rates_struct(),
implied_volatility(),
implied_volatility_with_term_struct()
Other Equity Independent Default Intensity:
american(),
american_implied_volatility(),
blackscholes(),
equivalent_bs_vola_to_jump(),
equivalent_jump_vola_to_bs(),
implied_volatilities(),
implied_volatilities_with_rates_struct(),
implied_volatility(),
implied_volatility_with_term_struct()
black_scholes_on_term_structures(callput=-1, S0=100, K=90, time=1,
discount_factor_fcn = function(T, t, ...) {
exp(-0.03 * (T - t))
},
survival_probability_fcn = function(T, t, ...) {
exp(-0.07 * (T - t))
},
variance_cumulation_fcn = function(T, t) {
0.45 ^ 2 * (T - t)
})
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.