check_variance_cumulation_fcn: Check that a variance cumulation function is nondecreasing

View source: R/checkinputs.R

check_variance_cumulation_fcnR Documentation

Check that a variance cumulation function is nondecreasing

Description

Total variance accumulated from a fixed origin can never decrease as the horizon moves forward in time. This routine evaluates the supplied variance_cumulation_fcn on the ordered time_pts. Emits a warning whenever the cumulated variance fails to be nondecreasing.

Usage

check_variance_cumulation_fcn(variance_cumulation_fcn, time_pts)

Arguments

variance_cumulation_fcn

A function for computing total stock variance, with arguments T, t, returning the variance cumulated from time t to time T

time_pts

A vector of time points at which to test that variance_cumulation_fcn is nondecreasing

Value

TRUE if the cumulated variance is nondecreasing across time_pts, otherwise FALSE

See Also

Other Input Checking: check_discount_factor_fcn(), check_survival_probability_fcn(), warn_once_negative_default_intensity()


ragtop documentation built on June 20, 2026, 5:06 p.m.