| integrate_pde | R Documentation |
Use an implicit integration scheme to numerically integrate
the pricing differential equation for each of the given instruments,
backwardating from time Tmax to time 0.
integrate_pde(
z,
min_num_time_steps,
S0,
Tmax,
instruments,
stock_level_fcn,
discount_factor_fcn,
default_intensity_fcn,
variance_cumulation_fcn,
dividends = NULL
)
z |
Space grid value morphable to stock prices using |
min_num_time_steps |
The minimum number of timesteps used. Calls, puts and coupons may result in extra timesteps taken. |
S0 |
Time zero price of the base equity |
Tmax |
The maximum time on the grid, from which all backwardation steps will take place. |
instruments |
A list of instruments to be priced. Each
one must have a |
stock_level_fcn |
A function for changing space grid value to stock
prices, with arguments |
discount_factor_fcn |
A function for computing present values to
time |
default_intensity_fcn |
A function for computing default intensity
occurring during this timestep, dependent on time and stock price, with
arguments |
variance_cumulation_fcn |
A function for computing total stock variance
occurring during this timestep, with arguments |
dividends |
A |
A grid of present values of derivative prices, adapted to z at
each timestep. Time zero value will appear in the first index.
Other Implicit Grid Solver:
construct_implicit_grid_structure(),
find_present_value(),
form_present_value_grid(),
infer_conforming_time_grid(),
iterate_grid_from_timestep(),
pde_matrix_solve(),
take_implicit_timestep(),
timestep_instruments()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.