shift_for_dividends: Shift a set of grid values for dividends paid, using spline...

View source: R/cashflows.R

shift_for_dividendsR Documentation

Shift a set of grid values for dividends paid, using spline interpolation

Description

Shift a set of grid values for dividends paid, using spline interpolation

Usage

shift_for_dividends(grid_values_before_shift, stock_prices, div_sum)

Arguments

grid_values_before_shift

Values on grid before accounting for expected dividends

stock_prices

Stock prices for which to shift the grid

div_sum

Sum of dividend values at each grid point

Value

An object like grid_values_before_shift with entries shifted according to the dividend sums

See Also

Other Dividends: adjust_for_dividends(), time_adj_dividends()


ragtop documentation built on June 20, 2026, 5:06 p.m.