View source: R/term_structures.R
| spot_to_df_fcn | R Documentation |
Use a piecewise constant approximation to the given spot curve to generate a function capable of returning corresponding discount factors
spot_to_df_fcn(yield_curve)
yield_curve |
A data.frame with numeric columns |
A function taking two time arguments, which returns the discount factor from the second to the first
disct_fcn = ragtop::spot_to_df_fcn(
data.frame(time=c(1, 5, 10, 15),
rate=c(0.01, 0.02, 0.03, 0.05)))
print(disct_fcn(1, 0.5))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.