View source: R/term_structures.R
| treasury_df | R Documentation |
This is a caching wrapper for treasury_df_raw
treasury_df(..., envir = parent.frame())
... |
Arguments passed to |
envir |
Environment passed to |
A function taking two time arguments, which returns the discount factor from the second to the first (see spot_to_df_fcn)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.