treasury_df_raw: Get a US Treasury curve discount factor function

View source: R/term_structures.R

treasury_df_rawR Documentation

Get a US Treasury curve discount factor function

Description

Get a US Treasury curve discount factor function

Usage

treasury_df_raw(on_date)

Arguments

on_date

Date for which to query for the curve, year-month-day format

Value

A function taking two time arguments, which returns the discount factor from the second to the first


ragtop documentation built on June 20, 2026, 5:06 p.m.