| TIME_RESOLUTION_FACTOR | R Documentation |
Constant to define when times are considered so close to each other that they should be treated as simultaneous
TIME_RESOLUTION_FACTOR
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.