| TIME_RESOLUTION_SIGNIF_DIGITS | R Documentation |
Constant to define when times are considered so close to each other that they should be treated as simultaneous, in terms of significant digits
TIME_RESOLUTION_SIGNIF_DIGITS
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.