| check_survival_probability_fcn | R Documentation |
Survival probabilities accumulated from a fixed origin can never
increase as the horizon moves forward in time, and must always lie
in the closed interval [0,1]. This routine evaluates the
supplied survival_probability_fcn on the ordered
time_pts. Emits a warning whenever the probabilities are
increasing or fall outside [0,1].
check_survival_probability_fcn(survival_probability_fcn, time_pts)
survival_probability_fcn |
A function for computing survival
probabilities, with arguments |
time_pts |
A vector of time points at which to test the
behavior of |
TRUE if the survival probabilities are nonincreasing
and within [0,1] across time_pts, otherwise FALSE
Other Input Checking:
check_discount_factor_fcn(),
check_variance_cumulation_fcn(),
warn_once_negative_default_intensity()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.