| check_variance_cumulation_fcn | R Documentation |
Total variance accumulated from a fixed origin can never
decrease as the horizon moves forward in time. This routine
evaluates the supplied variance_cumulation_fcn on the ordered
time_pts. Emits a warning whenever the cumulated variance fails to
be nondecreasing.
check_variance_cumulation_fcn(variance_cumulation_fcn, time_pts)
variance_cumulation_fcn |
A function for computing total stock
variance, with arguments |
time_pts |
A vector of time points at which to test that
|
TRUE if the cumulated variance is nondecreasing across
time_pts, otherwise FALSE
Other Input Checking:
check_discount_factor_fcn(),
check_survival_probability_fcn(),
warn_once_negative_default_intensity()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.