View source: R/term_structures.R
| treasury_df_raw | R Documentation |
Get a US Treasury curve discount factor function
treasury_df_raw(on_date)
on_date |
Date for which to query for the curve, year-month-day format |
A function taking two time arguments, which returns the discount factor from the second to the first
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.